@@ -17,9 +17,7 @@
 /* this flips all the bits in a byte array at byte intervals
  */
 
-void flipBits(p, len)
-     byte *p;
-     unsigned int len;
+void flipBits(byte *p, unsigned int len)
 { static int init= 0;
   static byte flipped[256];
 
